@@ -7,6 +7,9 @@ use crate::{
     external::Vcs,
     mit::{Author, Authors},
 };
+
+/// Libgit2 vcs implementation
+#[allow(missing_debug_implementations)]
 pub struct Git2 {
     config_snapshot: git2::Config,
     config_live: git2::Config,
@@ -119,7 +122,7 @@ impl TryFrom<PathBuf> for Git2 {
     }
 }
 
-impl TryFrom<&'_ Git2> for Authors {
+impl TryFrom<&'_ Git2> for Authors<'_> {
     type Error = Report;
 
     fn try_from(vcs: &'_ Git2) -> Result<Self, Self::Error> {
@@ -154,17 +157,18 @@ impl TryFrom<&'_ Git2> for Authors {
 
                     match (name, email, signingkey) {
                         (Some(name), Some(email), None) => {
-                            Some((key, Author::new(&name, &email, None)))
-                        }
-                        (Some(name), Some(email), Some(signingkey)) => {
-                            Some((key, Author::new(&name, &email, Some(&signingkey))))
+                            Some((key, Author::new(name.into(), email.into(), None)))
                         }
+                        (Some(name), Some(email), Some(signingkey)) => Some((
+                            key,
+                            Author::new(name.into(), email.into(), Some(signingkey.into())),
+                        )),
                         _ => None,
                     }
                 })
                 .fold(
                     BTreeMap::new(),
-                    |mut acc: BTreeMap<String, Author>, (key, value): (&String, Author)| {
+                    |mut acc: BTreeMap<String, Author<'_>>, (key, value): (&String, Author<'_>)| {
                         acc.insert(key.clone(), value);
                         acc
                     },
